@@ -1,28 +1,31 @@
 import argparse
 from enum import Enum
-from genericpath import isfile
-from runpy import run_path
-from typing import List
-from arkitekt.cli.dev.autoreload import watch_directory_and_restart
+from arkitekt.cli.dev.automirror import watch_directory_and_mirror
+from arkitekt.cli.dev.autostage import watch_directory_and_stage
+from arkitekt.cli.prod.run import import_directory_and_start
 from arkitekt.cli.prod.waitfor import wait_for_connection
 from fakts import Fakts
-from fakts.beacon.beacon import FaktsEndpoint
-from fakts.grants.beacon import BeaconGrant
-from fakts.grants.endpoint import EndpointGrant
 from fakts.grants.cli.clibeacon import CLIBeaconGrant
-from fakts.grants.yaml import YamlGrant
 from herre import Herre
 from rich.console import Console
 from rich.prompt import Prompt, Confirm
 import os
 import asyncio
 
+try:
+    from rich.traceback import install
+
+    install()
+except:
+    pass
+
 directory = os.getcwd()
 
 
 class ArkitektOptions(str, Enum):
     INIT = "init"
     DEV = "dev"
+    MIRROR = "mirror"
     LOGOUT = "logout"
     LOGIN = "login"
     RUN = "run"
@@ -30,11 +33,9 @@ class ArkitektOptions(str, Enum):
 
 
 agent_script = f'''
-from arkitekt.agents.script import ScriptAgent
+from arkitekt import register
 
-agent = ScriptAgent()
-
-@agent.register()
+@register()
 def test_show(name: str)-> str:
     """Demo Node
 
@@ -49,7 +50,6 @@ def test_show(name: str)-> str:
     """
     return name
 
-agent.provide()
 
 '''
 
@@ -57,9 +57,10 @@ mikro_script = """
 from mikro import gql
 
 x = gql('''
-query { myrepresentations {
-    id
-}
+query {
+    myrepresentations {
+        id
+    }
 }
 ''')
 
@@ -101,7 +102,20 @@ def main(
             console.print(f"{app_directory} does not have a valid fakts.yaml")
             return
 
-        asyncio.run(watch_directory_and_restart(path, entrypoint="run"))
+        fakts = Fakts(grants=[], fakts_path=fakts_path)
+        asyncio.run(watch_directory_and_stage(path, entrypoint="run"))
+
+    if script == ArkitektOptions.MIRROR:
+
+        if not os.path.isfile(run_script_path):
+            console.print(f"Could't find a run.py in {app_directory} {run_script_path}")
+            return
+        if not os.path.isfile(fakts_path):
+            console.print(f"{app_directory} does not have a valid fakts.yaml")
+            return
+
+        fakts = Fakts(grants=[], fakts_path=fakts_path)
+        asyncio.run(watch_directory_and_mirror(path, entrypoint="run"))
 
     if script == ArkitektOptions.RUN:
 
@@ -112,7 +126,8 @@ def main(
             console.print(f"{app_directory} does not have a valid fakts.yaml")
             return
 
-        run_path(run_script_path)
+        fakts = Fakts(grants=[], fakts_path=fakts_path)
+        asyncio.run(import_directory_and_start(path, entrypoint="run"))
 
     if script == ArkitektOptions.LOGIN:
 
